/*
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: _STARTUPINFOW
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class _STARTUPINFOW {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int _cbOffset_;
	public static final int _cbReserved2Offset_;
	public static final int _dwFillAttributeOffset_;
	public static final int _dwFlagsOffset_;
	public static final int _dwXOffset_;
	public static final int _dwXCountCharsOffset_;
	public static final int _dwXSizeOffset_;
	public static final int _dwYOffset_;
	public static final int _dwYCountCharsOffset_;
	public static final int _dwYSizeOffset_;
	public static final int _hStdErrorOffset_;
	public static final int _hStdInputOffset_;
	public static final int _hStdOutputOffset_;
	public static final int _lpDesktopOffset_;
	public static final int _lpReservedOffset_;
	public static final int _lpReserved2Offset_;
	public static final int _lpTitleOffset_;
	public static final int _wShowWindowOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		_cbOffset_ = 0;
		_cbReserved2Offset_ = 0;
		_dwFillAttributeOffset_ = 0;
		_dwFlagsOffset_ = 0;
		_dwXOffset_ = 0;
		_dwXCountCharsOffset_ = 0;
		_dwXSizeOffset_ = 0;
		_dwYOffset_ = 0;
		_dwYCountCharsOffset_ = 0;
		_dwYSizeOffset_ = 0;
		_hStdErrorOffset_ = 0;
		_hStdInputOffset_ = 0;
		_hStdOutputOffset_ = 0;
		_lpDesktopOffset_ = 0;
		_lpReservedOffset_ = 0;
		_lpReserved2Offset_ = 0;
		_lpTitleOffset_ = 0;
		_wShowWindowOffset_ = 0;
	}

}
